=================
ControlledProcess
=================

.. autoclass:: openmsistream.utilities.ControlledProcess
   :private-members:
   :exclude-members: _print_still_alive, _check_control_command_queue